@@ -8,7 +8,14 @@ from ..serialise import Model, ModelList, Timestamp
 
 @dataclass(repr=False)
 class SimpleShow(Show):
-    """Simplified show object."""
+    """
+    Simplified show object.
+
+    :attr:`total_episodes` is undocumented by Spotify,
+    so it might be missing or removed in a future version.
+    """
+
+    total_episodes: int = None
 
 
 @dataclass(repr=False)
